@@ -2,8 +2,8 @@ from rest_framework import serializers
 
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedPartitionSerializer, NestedLinuxVolumeSerializer
-from netbox_storage.models import Drive, Filesystem, Partition, LinuxVolume, StorageConfigurationLinuxVolume
+    NestedPartitionSerializer, NestedMountedVolumeSerializer
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationLinuxVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -60,18 +60,19 @@ class PartitionSerializer(serializers.ModelSerializer):
         )
 
 
-class LinuxVolumeSerializer(serializers.ModelSerializer):
+class MountedVolumeSerializer(serializers.ModelSerializer):
     fs = NestedFilesystemSerializer(required=False, allow_null=True)
     partition = NestedPartitionSerializer(required=False, allow_null=True)
 
     class Meta:
-        model = LinuxVolume
+        model = MountedVolume
         fields = (
             "id",
             "partition",
             "fs",
             "size",
             "path",
+            "label",
             "description",
             "created",
             "last_updated",
@@ -80,7 +81,7 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
 
 
 class StorageConfigurationLinuxVolumeSerializer(serializers.ModelSerializer):
-    linux_volume = NestedLinuxVolumeSerializer(required=False, allow_null=True)
+    linux_volume = NestedMountedVolumeSerializer(required=False, allow_null=True)
     virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
 
     class Meta:
