@@ -1,16 +1,20 @@
+import django_filters
 from django.db.models import Q
 
 from netbox.filtersets import NetBoxModelFilterSet
 
-from netbox_storage.models import Partition
+from netbox_storage.models import Partition, Drive
 
 
 class PartitionFilter(NetBoxModelFilterSet):
     """Filter capabilities for Partition instances."""
+    drive_id = django_filters.ModelMultipleChoiceFilter(
+        queryset=Drive.objects.all(),
+    )
 
     class Meta:
         model = Partition
-        fields = ("drive", "device", "size", "type")
+        fields = ("device", "size", "type")
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
